@@ -17,7 +17,7 @@ our @EXPORT_OK = qw(
     );
 our @EXPORT = @EXPORT_OK;
 
-our $VERSION="3.1.00";
+our $VERSION="3.1.01";
 
 our @MANIFEST = (
 'clear.sh',
@@ -1500,7 +1500,7 @@ grant REPLICATION SLAVE on *.* to _DBUSERREPL_@'_REMOTE_ACCESS_' identified by '
 delete from user where password='';
 delete from db where user='';
 flush privileges;
-create schema if not exists test;
+create database if not exists test;
 
 GRANTS_MYSQL
 
@@ -1566,7 +1566,9 @@ then
     cp $SBDIR/grants_5_7_6.mysql $SBDIR/grants.mysql
 fi
 # END UGLY WORKAROUND
-$MYSQL -u root < $SBDIR/grants.mysql
+VERBOSE_SQL=''
+[ -n "$SBDEBUG" ] && VERBOSE_SQL=-v
+$MYSQL -u root $VERBOSE_SQL < $SBDIR/grants.mysql
 # echo "source $SBDIR/grants.mysql" | $SBDIR/use -u root --password= 
 # $SBDIR/my sqldump _EVENTS_OPTIONS_ mysql > $SBDIR/rescue_mysql_dump.sql
 LOAD_GRANTS_SCRIPT
@@ -1637,7 +1639,7 @@ END_DEFAULT_CONNECTION_JSON
             "DriverManager" : "con=DriverManager.getConnection(\\\"jdbc:mysql://127.0.0.1:_SERVERPORT_/test\\\", \\\"_DBUSER_\\\", \\\"_DBPASSWORD_\\\")"            
         },
         "ruby" : {
-            "mysql" : "connection = Mysql.new '127.0.0.1', '_DBUSER_', '_DBPASSWORD_', 'test', _SERVER_PORT_"
+            "mysql" : "connection = Mysql.new '127.0.0.1', '_DBUSER_', '_DBPASSWORD_', 'test', _SERVERPORT_"
         },
         "shell" : {
             "generic": "_BASEDIR_/bin/mysql -h 127.0.0.1 -P _SERVERPORT_ -u _DBUSER_ -p_DBPASSWORD_"
